==> haskell-stm-hamt-1.2.1-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-hamt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-hamt
version:              1.2.1
visibility:           public
id:                   stm-hamt-1.2.1-KqKMFTtVzcdEIXxADFA2Et
key:                  stm-hamt-1.2.1-KqKMFTtVzcdEIXxADFA2Et
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  b039ad8bcd2365cd94b5a3a03a699ddd
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.2.8/site-local/stm-hamt-1.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stm-hamt-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.1-KqKMFTtVzcdEIXxADFA2Et
depends:
    base-4.16.4.0 deferred-folds-0.9.18.6-2ys39PrhbvW91umLutm1VH
    focus-1.0.3.2-EUbgtKNJbes9dPuZsX1exJ
    hashable-1.4.4.0-1DKi0WUbpLrE22bUerprT9
    list-t-1.0.5.5-9hix5nWzOCyHf3qVrsgvv6
    primitive-0.7.4.0-LS5OACsFMkWJjOUaCwrwBF
    primitive-extras-0.10.2.1-1OByv5kYMzJ7MkpwE0Gv9b
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-hamt-1.2.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-hamt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-hamt
version:              1.2.1
visibility:           public
id:                   stm-hamt-1.2.1-Gw2TFOXoW6K5jFvjgjPyiH
key:                  stm-hamt-1.2.1-Gw2TFOXoW6K5jFvjgjPyiH
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  5a975114d1741eee1c2243d755c800f3
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.2.8/site-local/stm-hamt-1.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stm-hamt-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.1-Gw2TFOXoW6K5jFvjgjPyiH
depends:
    base-4.16.4.0 deferred-folds-0.9.18.6-FS5lT57nJn6JZE4JAal1c5
    focus-1.0.3.2-4R7IPQaz0jhB5EmPKFBybF
    hashable-1.4.4.0-JynHLbpSPE72B4j6uWctY4
    list-t-1.0.5.5-3ogJUhW78jx2ivatWvuSUD
    primitive-0.7.4.0-6AwD3HztCbd2gLkP35eH21
    primitive-extras-0.10.2.1-Gd7OjELaG9LHrJN5ehT3Iw
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
